Learn R Programming

afthd (version 1.1.0)

lgnbyuni: Bayesian univariate analysis of AFT model with log normal distribution.

Description

Provides posterior estimates of AFT model with log normal distribution using Bayesian for univariate in high dimensional gene expression data. It also deals covariates with missing values.

Usage

lgnbyuni(m, n, STime, Event, nc, ni, data)

Arguments

m

Starting column number of covariates of study from high dimensional entered data.

n

Ending column number of covariates of study from high dimensional entered data.

STime

name of survival time in data

Event

name of event in data. 0 is for censored and 1 for occurrence of event.

nc

number of MCMC chain.

ni

number of MCMC iteration to update the outcome.

data

High dimensional gene expression data that contains event status, survival time and and set of covariates.

Value

Data frame is containing posterior estimates (Coef, SD, Credible Interval, Rhat, n.eff) of regression coefficient of selected covariates and deviance. Result shows together for all covariates chosen from column m to n.

Details

This function deals covariates (in data) with missing values. Missing value in any column (covariate) is replaced by mean of that particular covariate. AFT model is log-linear regression model for survival time \( T_1 \),\( T_2 \),..,\(T_n \). i.e., $$log(T_i)= x_i'\beta +\sigma\epsilon_i ;~\epsilon_i \sim F_\epsilon (.)~which~is~iid $$ Where \( F_\epsilon \) is known cdf which is defined on real line. When baseline distribution is normal then T follows log normal distribution. $$ T \sim LN(x'\beta,1/\tau) $$

References

Prabhash et al(2016) <doi:10.21307/stattrans-2016-046>

See Also

lgnbymv, wbysuni, lgstbyuni

Examples

Run this code
# NOT RUN {
##
data(hdata)
lgnbyuni(10,12,STime="os",Event="death",2,10,hdata)
##
# }

Run the code above in your browser using DataLab