wbyscrku: Bayesian univariate estimates for competing risk gene expression data using AFT model.
Description
Provides univariate estimate of AFT model using MCMC for competing risk high dimensional gene expression data. It also dea with missing values.
Usage
wbyscrku(m, n, STime, Event, nc, ni, data)
Arguments
m
Starting column number of covariates of study from high dimensional entered data.
n
Ending column number of covariates of study from high dimensional entered data.
STime
name of survival time in data.
Event
name of event status in data. 0 is for censored and 1 for occurrence of event of interest and 2 for occurrence of event due to other causes.
nc
number of markov chain.
ni
number of iteration for MCMC.
data
High dimensional gene expression data that contains event status with competing risk, survival time and and set of covariates.
Value
posterior estimates (Coef, SD, Credible Interval) of regression coefficient of covariate(which is/are chosen as columns in data) in model and deviance are there. Outcome shows together for all covariates chosen from column m to n.
Details
Here AFT model has been used with weibull distribution.
This function deals covariates (in data) with missing values. Missing value in any column(covariate) is replaced by mean of that particular covariate.
References
Prabhash et al(2016) <doi:10.21307/stattrans-2016-046>