Learn R Programming

afthd (version 1.1.0)

wbysuni: Posterior univariate estimates of AFT model with weibull distribution using MCMC.

Description

Provides posterior estimates of AFT model with weibull distribution using MCMC for univariate in high dimensional gene expression data. It also deals covariates with missing values.

Usage

wbysuni(m, n, STime, Event, nc, ni, data)

Arguments

m

Starting column number of covariates of study from high dimensional entered data.

n

Ending column number of covariates of study from high dimensional entered data.

STime

name of survival time in data

Event

name of event status in data. 0 is for censored and 1 for occurrence of event.

nc

number of markov chain.

ni

number of iteration for MCMC.

data

High dimensional gene expression data that contains event status, survival time and and set of covariates.

Value

Data frame is containing posterior estimates (Coef, SD, Credible Interval, Rhat, n.eff) of regression coefficient for covariates and deviance. Result shows together for all covariates chosen from column m to n.

Details

This function deals covariates (in data) with missing values. Missing value in any column (covariate) is replaced by mean of that particular covariate. AFT model is log-linear regression model for survival time \( T_{1}\),\( T_{2}\),..,\(T_{n}\). i.e., $$log(T_i)= x_i'\beta +\sigma\epsilon_i ;~\epsilon_i \sim F_\epsilon (.)~which~is~iid $$ Where \( F_\epsilon \) is known cdf which is defined on real line. Here, when baseline distribution is extreme value then T follows weibull distribution. To make interpretation of regression coefficients simpler, using extreme value distribution with median 0. So using weibull distribution that leads to AFT model when $$ T \sim Weib(\sqrt{\tau},log(2)\exp(-x'\beta \sqrt{\tau})) $$

References

Prabhash et al(2016) <doi:10.21307/stattrans-2016-046>

See Also

pvaft, wbysmv, rglwbysu, wbyscrku

Examples

Run this code
# NOT RUN {
##
data(hdata)
wbysuni(9,13,STime="os",Event="death",1,10,hdata)
##
# }

Run the code above in your browser using DataLab