Provides estimate of AFT model with log logistic distribution using MCMC for univariate in high dimensional gene expression data. It also deals covariates with missing values.
lgstbyuni(m, n, STime, Event, nc, ni, data)Starting column number of covariates of study from high dimensional entered data.
Ending column number of covariates of study from high dimensional entered data.
name of survival time in data
name of event in data
number of chain used in model.
number of iteration used in model.
High dimensional gene expression data that contains event status, survival time and and set of covariates.
Data frame is containing posterior estimates (Coef, SD, Credible Interval, Rhat, n.eff) of regression coefficient of selected covariates and deviance. Result shows together for all covariates chosen from column m to n.
This function deals covariates (in data) with missing values. Missing value in any column (covariate) is replaced by mean of that particular covariate. AFT model is log-linear regression model for survival time \( T_{1}\),\( T_{2}\),..,\(T_{n}\). i.e., $$log(T_i)= x_i'\beta +\sigma\epsilon_i ;~\epsilon_i \sim F_\epsilon (.)~which~is~iid $$ Where \( F_\epsilon \) is known cdf which is defined on real line. When baseline distribution is logistic then T follows log logistic distribution. $$ T \sim Log-Logis(x'\beta,\sqrt{\tau)} $$
Prabhash et al(2016) <doi:10.21307/stattrans-2016-046>
wbysmv, lgnbymv, lgstbymvs
# NOT RUN {
##
data(hdata)
lgstbyuni(12,14,STime="os",Event="death",3,100,hdata)
##
# }
Run the code above in your browser using DataLab